pub enum ImportOption {
None,
PreferDoppler,
PreferIntegration,
}Expand description
An option indicating if and how Doppler should attempt to import secrets from the sync destination
Variants
None
An option indicating if and how Doppler should attempt to import secrets from the sync destination
PreferDoppler
An option indicating if and how Doppler should attempt to import secrets from the sync destination
PreferIntegration
An option indicating if and how Doppler should attempt to import secrets from the sync destination