pub struct CreateSyncRequest {
pub integration: String,
pub data: Value,
pub import_option: Option<String>,
pub await_initial_sync: Option<bool>,
}Expand description
CreateSyncRequest
Fields
integration: StringThe integration slug which the sync will use
data: ValueConfiguration data for the sync
import_option: Option<String>An option indicating if and how Doppler should attempt to import secrets from the sync destination An option indicating if and how Doppler should attempt to import secrets from the sync destination An option indicating if and how Doppler should attempt to import secrets from the sync destination An option indicating if and how Doppler should attempt to import secrets from the sync destination
await_initial_sync: Option<bool>Causes sync creation to wait for the initial sync to complete before returning.
Implementations
Sourceimpl CreateSyncRequest
impl CreateSyncRequest
pub fn new(integration: String, data: Value) -> CreateSyncRequest