pub struct UpdateSecretNoteRequest {
pub secret: String,
pub note: String,
}Expand description
UpdateSecretNoteRequest
Fields
secret: StringThe name of the secret
note: StringThe note you want to set on the secret. This note will be applied to the specified secret in all environments.
Implementations
Sourceimpl UpdateSecretNoteRequest
impl UpdateSecretNoteRequest
pub fn new(secret: String, note: String) -> UpdateSecretNoteRequest